@@ -3,6 +3,7 @@ import argparse
 import dataclasses
 from datetime import datetime
 import sys
+import logging
 from typing import Any, Dict
 
 import buildflow
@@ -11,6 +12,7 @@ from buildflow import Flow
 # Parser to allow run time configuration of arguments
 parser = argparse.ArgumentParser()
 parser.add_argument('--gcp_project', type=str, required=True)
+parser.add_argument('--bigquery_table', type=str, default='taxi_ride_data')
 args, _ = parser.parse_known_args(sys.argv)
 
 # Set up a subscriber for the source.
@@ -21,7 +23,7 @@ input_sub = buildflow.PubSubSource(
 # Set up a BigQuery table for the sink.
 # If this table does not exist yet BuildFlow will create it.
 output_table = buildflow.BigQuerySink(
-    table_id=f'{args.gcp_project}.buildflow_walkthrough.taxi_ride_data')
+    table_id=f'{args.gcp_project}.buildflow_walkthrough.{args.bigquery_table}')
 
 
 # Define an output type for our pipeline.
@@ -50,4 +52,4 @@ def process(element: Dict[str, Any]) -> TaxiOutput:
 
 
 # Run our flow.
-flow.run()
\ No newline at end of file
+flow.run().output()
\ No newline at end of file
