@@ -27,4 +27,4 @@ class MyProcessor(buildflow.Processor):
         return Output(payload['val'] + 1)
 
 
-flow.run(MyProcessor())
+flow.run(MyProcessor()).output()
